package Bundle::Advent::Year2007;

our $VERSION = '0.02';

1;

__END__

=pod

=head1 NAME

Bundle::Advent::Year2007 - Modules of the 2007 Perl Advent Calendar

=head1 VERSION

Version 0.02

=head1 SYNOPSIS

Bundle for the modules featured in the 2007 Perl Advent Calendar:
L<http://www.perladvent.org/2007/>.

    $ cpan Bundle::Advent::Year2007

=head1 CONTENTS

Data::ICal - L<pod|Data::ICal>, L<http://www.perladvent.org/2007/01/>

Parallel::Jobs - L<pod|Parallel::Jobs>, L<http://www.perladvent.org/2007/02/>

DBIx::Profile - L<pod|DBIx::Profile>, L<http://www.perladvent.org/2007/03/>

Test::Differences - L<pod|Test::Differences>, L<http://www.perladvent.org/2007/04/>

File::Which - L<pod|File::Which>, L<http://www.perladvent.org/2007/05/>

File::ReadBackwards - L<pod|File::ReadBackwards>, L<http://www.perladvent.org/2007/06/>

TimeDate - L<pod|TimeDate>, L<http://www.perladvent.org/2007/07/>

Math::Combinatorics - L<pod|Math::Combinatorics>, L<http://www.perladvent.org/2007/08/>

Sub::Versive - L<pod|Sub::Versive>, L<http://www.perladvent.org/2007/09/>

forks - L<pod|forks>, L<http://www.perladvent.org/2007/11/>

DateTime::TimeZone - L<pod|DateTime::TimeZone>, L<http://www.perladvent.org/2007/16/>

Pod::Simple::Subclassing - L<pod|Pod::Simple::Subclassing>, L<http://www.perladvent.org/2007/17/>

Acme::Curses:Marquee - L<pod|Acme::Curses:Marquee>, L<http://www.perladvent.org/2007/18/>

B::Fathom - L<pod|B::Fathom>, L<http://www.perladvent.org/2007/23/>

Text::vCard - L<pod|Text::vCard>, L<http://www.perladvent.org/2007/24/>

Time::Out - L<pod|Time::Out>, L<http://www.perladvent.org/2007/25/>



=head1 AUTHOR

David Westbrook (CPAN: davidrw), C<< <dwestbrook at gmail.com> >>


=head1 SUPPORT

You can find documentation for this module with the perldoc command.

    perldoc Bundle::Advent::Year2007

Otherwise, see L<Advent::Bundles>.


=head1 COPYRIGHT & LICENSE

Copyright 2008 David Westbrook, all rights reserved.

This program is free software; you can redistribute it and/or modify it
under the same terms as Perl itself.


=cut
