package Bundle::Advent::Year2000;

our $VERSION = '0.02';

1;

__END__

=pod

=head1 NAME

Bundle::Advent::Year2000 - Modules of the 2000 Perl Advent Calendar

=head1 VERSION

Version 0.02

=head1 SYNOPSIS

Bundle for the modules featured in the 2000 Perl Advent Calendar:
L<http://www.perladvent.org/2000/>.

    $ cpan Bundle::Advent::Year2000

=head1 CONTENTS

Data::Dumper - L<pod|Data::Dumper>, L<http://www.perladvent.org/2000/01/>

LWP::Simple - L<pod|LWP::Simple>, L<http://www.perladvent.org/2000/02/>

POE::Component::IRC - L<pod|POE::Component::IRC>, L<http://www.perladvent.org/2000/03/>

Exporter - L<pod|Exporter>, L<http://www.perladvent.org/2000/04/>

Time::Local - L<pod|Time::Local>, L<http://www.perladvent.org/2000/05/>

Time::Object - L<pod|Time::Object>, L<http://www.perladvent.org/2000/06/>

Tie::Scalar::Timeout - L<pod|Tie::Scalar::Timeout>, L<http://www.perladvent.org/2000/07/>

Tie::HashDefaults - L<pod|Tie::HashDefaults>, L<http://www.perladvent.org/2000/08/>

Crypt::RC4 - L<pod|Crypt::RC4>, L<http://www.perladvent.org/2000/09/>

GD - L<pod|GD>, L<http://www.perladvent.org/2000/10/>

Image::Imlib2 - L<pod|Image::Imlib2>, L<http://www.perladvent.org/2000/11/>

File::Remote - L<pod|File::Remote>, L<http://www.perladvent.org/2000/12/>

XML::Grove - L<pod|XML::Grove>, L<http://www.perladvent.org/2000/14/>

Getopt::Long - L<pod|Getopt::Long>, L<http://www.perladvent.org/2000/15/>

File::Find - L<pod|File::Find>, L<http://www.perladvent.org/2000/16/>

DBI - L<pod|DBI>, L<http://www.perladvent.org/2000/17/>

Memoize - L<pod|Memoize>, L<http://www.perladvent.org/2000/18/>

Storable - L<pod|Storable>, L<http://www.perladvent.org/2000/19/>

Inline - L<pod|Inline>, L<http://www.perladvent.org/2000/20/>

Class::Virtual - L<pod|Class::Virtual>, L<http://www.perladvent.org/2000/21/>

Class::Multimethods - L<pod|Class::Multimethods>, L<http://www.perladvent.org/2000/22/>

Symbol::Approx::Sub - L<pod|Symbol::Approx::Sub>, L<http://www.perladvent.org/2000/23/>

Template - L<pod|Template>, L<http://www.perladvent.org/2000/24/>

Date::Christmas - L<pod|Date::Christmas>, L<http://www.perladvent.org/2000/25/>



=head1 AUTHOR

David Westbrook (CPAN: davidrw), C<< <dwestbrook at gmail.com> >>


=head1 SUPPORT

You can find documentation for this module with the perldoc command.

    perldoc Bundle::Advent::Year2000

Otherwise, see L<Advent::Bundles>.


=head1 COPYRIGHT & LICENSE

Copyright 2008 David Westbrook, all rights reserved.

This program is free software; you can redistribute it and/or modify it
under the same terms as Perl itself.


=cut
