package Bundle::Advent::Year2002;

our $VERSION = '0.02';

1;

__END__

=pod

=head1 NAME

Bundle::Advent::Year2002 - Modules of the 2002 Perl Advent Calendar

=head1 VERSION

Version 0.02

=head1 SYNOPSIS

Bundle for the modules featured in the 2002 Perl Advent Calendar:
L<http://www.perladvent.org/2002/>.

    $ cpan Bundle::Advent::Year2002

=head1 CONTENTS

URI::Find - L<pod|URI::Find>, L<http://www.perladvent.org/2002/01/>

IO::AtomicFile - L<pod|IO::AtomicFile>, L<http://www.perladvent.org/2002/02/>

DBD::SQLite - L<pod|DBD::SQLite>, L<http://www.perladvent.org/2002/03/>

Test::Builder - L<pod|Test::Builder>, L<http://www.perladvent.org/2002/04/>

Image::Size - L<pod|Image::Size>, L<http://www.perladvent.org/2002/05/>

Devel::Size - L<pod|Devel::Size>, L<http://www.perladvent.org/2002/06/>

File::MMagic - L<pod|File::MMagic>, L<http://www.perladvent.org/2002/07/>

XML::Handler::AxPoint - L<pod|XML::Handler::AxPoint>, L<http://www.perladvent.org/2002/08/>

XML::SAX - L<pod|XML::SAX>, L<http://www.perladvent.org/2002/09/>

Params::Validate - L<pod|Params::Validate>, L<http://www.perladvent.org/2002/10/>

File::Find::Rule - L<pod|File::Find::Rule>, L<http://www.perladvent.org/2002/11/>

Object::Realize::Later - L<pod|Object::Realize::Later>, L<http://www.perladvent.org/2002/12/>

Benchmark - L<pod|Benchmark>, L<http://www.perladvent.org/2002/13/>

Test::MockObject - L<pod|Test::MockObject>, L<http://www.perladvent.org/2002/14/>

YAML - L<pod|YAML>, L<http://www.perladvent.org/2002/15/>

WWW::Mechanize - L<pod|WWW::Mechanize>, L<http://www.perladvent.org/2002/16/>

Acme::Intraweb - L<pod|Acme::Intraweb>, L<http://www.perladvent.org/2002/17/>

CPANPLUS - L<pod|CPANPLUS>, L<http://www.perladvent.org/2002/18/>

Inline::TT - L<pod|Inline::TT>, L<http://www.perladvent.org/2002/19/>

Class::Data::Inheritable - L<pod|Class::Data::Inheritable>, L<http://www.perladvent.org/2002/20/>

Tie::File - L<pod|Tie::File>, L<http://www.perladvent.org/2002/21/>

XML::LibXML - L<pod|XML::LibXML>, L<http://www.perladvent.org/2002/22/>

Class::DBI - L<pod|Class::DBI>, L<http://www.perladvent.org/2002/23/>

Pixie - L<pod|Pixie>, L<http://www.perladvent.org/2002/24/>

Devel::DProf - L<pod|Devel::DProf>, L<http://www.perladvent.org/2002/25/>



=head1 AUTHOR

David Westbrook (CPAN: davidrw), C<< <dwestbrook at gmail.com> >>


=head1 SUPPORT

You can find documentation for this module with the perldoc command.

    perldoc Bundle::Advent::Year2002

Otherwise, see L<Advent::Bundles>.


=head1 COPYRIGHT & LICENSE

Copyright 2008 David Westbrook, all rights reserved.

This program is free software; you can redistribute it and/or modify it
under the same terms as Perl itself.


=cut
