package Bundle::Advent::Year2003;

our $VERSION = '0.02';

1;

__END__

=pod

=head1 NAME

Bundle::Advent::Year2003 - Modules of the 2003 Perl Advent Calendar

=head1 VERSION

Version 0.02

=head1 SYNOPSIS

Bundle for the modules featured in the 2003 Perl Advent Calendar:
L<http://www.perladvent.org/2003/>.

    $ cpan Bundle::Advent::Year2003

=head1 CONTENTS

CGI::Untaint - L<pod|CGI::Untaint>, L<http://www.perladvent.org/2003/01/>

HTML::Entities - L<pod|HTML::Entities>, L<http://www.perladvent.org/2003/02/>

Hook::LexWrap - L<pod|Hook::LexWrap>, L<http://www.perladvent.org/2003/03/>

PPerl - L<pod|PPerl>, L<http://www.perladvent.org/2003/04/>

Template::Extract - L<pod|Template::Extract>, L<http://www.perladvent.org/2003/05/>

Mail::SpamAssassin - L<pod|Mail::SpamAssassin>, L<http://www.perladvent.org/2003/06/>

Attribute::Handlers - L<pod|Attribute::Handlers>, L<http://www.perladvent.org/2003/07/>

CGI::Application - L<pod|CGI::Application>, L<http://www.perladvent.org/2003/08/>

Data::Dimensions - L<pod|Data::Dimensions>, L<http://www.perladvent.org/2003/09/>

Test::Inline - L<pod|Test::Inline>, L<http://www.perladvent.org/2003/10/>

File::chdir - L<pod|File::chdir>, L<http://www.perladvent.org/2003/11/>

Class::ISA - L<pod|Class::ISA>, L<http://www.perladvent.org/2003/12/>

only - L<pod|only>, L<http://www.perladvent.org/2003/13/>

Date::Parse - L<pod|Date::Parse>, L<http://www.perladvent.org/2003/14/>

Text::Glob - L<pod|Text::Glob>, L<http://www.perladvent.org/2003/15/>

Math::BigInt - L<pod|Math::BigInt>, L<http://www.perladvent.org/2003/16/>

diagnostics - L<pod|diagnostics>, L<http://www.perladvent.org/2003/17/>

PDF::Reuse - L<pod|PDF::Reuse>, L<http://www.perladvent.org/2003/18/>

Acme::Code::FreedomFighter - L<pod|Acme::Code::FreedomFighter>, L<http://www.perladvent.org/2003/19/>

Regexp::Common - L<Regexp::Common|pod>, L<http://www.perladvent.org/2003/20/> - Regex::Common (sic)

Inline::Java - L<pod|Inline::Java>, L<http://www.perladvent.org/2003/21/>

LWP::Simple - L<pod|LWP::Simple>, L<http://www.perladvent.org/2003/22/>

Data::Structure::Util - L<pod|Data::Structure::Util>, L<http://www.perladvent.org/2003/24/>

PAR - L<pod|PAR>, L<http://www.perladvent.org/2003/25/>



=head1 AUTHOR

David Westbrook (CPAN: davidrw), C<< <dwestbrook at gmail.com> >>


=head1 SUPPORT

You can find documentation for this module with the perldoc command.

    perldoc Bundle::Advent::Year2003

Otherwise, see L<Advent::Bundles>.


=head1 COPYRIGHT & LICENSE

Copyright 2008 David Westbrook, all rights reserved.

This program is free software; you can redistribute it and/or modify it
under the same terms as Perl itself.


=cut
