package Bundle::Advent::All;

our $VERSION = '0.04';

1;

__END__

=pod

=head1 NAME

Bundle::Advent::All - Modules of all years of the Perl Advent Calendar

=head1 VERSION

Version 0.04

=head1 SYNOPSIS

Bundle for the modules featured in any Perl Advent Calendar:
L<http://www.perladvent.org/archives.html>.

    $ cpan Bundle::Advent::All

=head1 CONTENTS

Bundle::Advent::Year2000

Bundle::Advent::Year2001

Bundle::Advent::Year2002

Bundle::Advent::Year2003

Bundle::Advent::Year2004

Bundle::Advent::Year2005

Bundle::Advent::Year2006

Bundle::Advent::Year2007

Bundle::Advent::Year2008

Bundle::Advent::Year2009


=head1 AUTHOR

David Westbrook (CPAN: davidrw), C<< <dwestbrook at gmail.com> >>


=head1 SUPPORT

You can find documentation for this module with the perldoc command.

    perldoc Bundle::Advent::All

Otherwise, see L<Advent::Bundles>.


=head1 COPYRIGHT & LICENSE

Copyright 2008 David Westbrook, all rights reserved.

This program is free software; you can redistribute it and/or modify it
under the same terms as Perl itself.


=cut
