package Advent::Bundles;

our $VERSION = '0.04';

1;

__END__

=pod

=head1 NAME

Advent::Bundles - Collection of year-by-year Bundles of the Perl Advent Calendar modules

=head1 VERSION

Version 0.04

=head1 SYNOPSIS

Provides bundles for the modules showcased in each year of the 2007 Perl Advent Calendar:
L<http://www.perladvent.org>.

To install a set of modules:

    $ cpan Bundle::Advent::Year2003
    $ cpan Bundle::Advent::Year2007

or:

    $ cpan Bundle::Advent::All



=head1 AUTHOR

David Westbrook (CPAN: davidrw), C<< <dwestbrook at gmail.com> >>

=head1 BUGS

Please report any bugs or feature requests to C<bug-bundle-advent at rt.cpan.org>, or through
the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Advent-Bundles>.  I will be notified, and then you'll
automatically be notified of progress on your bug as I make changes.




=head1 SUPPORT

You can find documentation for this module with the perldoc command.

    perldoc Advent::Bundles


You can also look for information at:

=over 4

=item * RT: CPAN's request tracker

L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Advent-Bundles>

=item * AnnoCPAN: Annotated CPAN documentation

L<http://annocpan.org/dist/Advent-Bundles>

=item * CPAN Ratings

L<http://cpanratings.perl.org/d/Advent-Bundles>

=item * Search CPAN

L<http://search.cpan.org/dist/Advent-Bundles/>

=back


=head1 ACKNOWLEDGEMENTS

The Perl Advent Calendar - L<http://www.perladvent.org> - for the annual production.


=head1 COPYRIGHT & LICENSE

Copyright 2008 David Westbrook, all rights reserved.

This program is free software; you can redistribute it and/or modify it
under the same terms as Perl itself.


=cut
