package Bundle::Advent::Year2006;

our $VERSION = '0.02';

1;

__END__

=pod

=head1 NAME

Bundle::Advent::Year2006 - Modules of the 2006 Perl Advent Calendar

=head1 VERSION

Version 0.02

=head1 SYNOPSIS

Bundle for the modules featured in the 2006 Perl Advent Calendar:
L<http://www.perladvent.org/2006/>.

    $ cpan Bundle::Advent::Year2006

=head1 CONTENTS

Devel::SmallProf - L<pod|Devel::SmallProf>, L<http://www.perladvent.org/2006/01/>

File::Find::Object - L<pod|File::Find::Object>, L<http://www.perladvent.org/2006/02/>

Treemap - L<pod|Treemap>, L<http://www.perladvent.org/2006/03/>

CGI::Minimal - L<pod|CGI::Minimal>, L<http://www.perladvent.org/2006/04/>

ack - L<pod|ack>, L<http://www.perladvent.org/2006/05/>

Module::Starter - L<pod|Module::Starter>, L<http://www.perladvent.org/2006/06/>

Acme::Don't - L<pod|Acme::Don't>, L<http://www.perladvent.org/2006/07/>

File::SortedSeek - L<pod|File::SortedSeek>, L<http://www.perladvent.org/2006/08/>

Devel::ptkdb - L<pod|Devel::ptkdb>, L<http://www.perladvent.org/2006/09/>

Fatal - L<pod|Fatal>, L<http://www.perladvent.org/2006/10/>

Graphics::ColorNames - L<pod|Graphics::ColorNames>, L<http://www.perladvent.org/2006/11/>

GD::Simple - L<pod|GD::Simple>, L<http://www.perladvent.org/2006/11/>

Pod::Usage - L<pod|Pod::Usage>, L<http://www.perladvent.org/2006/12/>

Geopt::Euclid - L<pod|Geopt::Euclid>, L<http://www.perladvent.org/2006/12/>

Shell - L<pod|Shell>, L<http://www.perladvent.org/2006/13/>

IPC::Run3 - L<pod|IPC::Run3>, L<http://www.perladvent.org/2006/14/>

File::HomeDir - L<pod|File::HomeDir>, L<http://www.perladvent.org/2006/15/>

Number::WithError - L<pod|Number::WithError>, L<http://www.perladvent.org/2006/16/>

Logfile::Rotate - L<pod|Logfile::Rotate>, L<http://www.perladvent.org/2006/17/>

Text::Diff - L<pod|Text::Diff>, L<http://www.perladvent.org/2006/18/>

XML::Feed - L<pod|XML::Feed>, L<http://www.perladvent.org/2006/19/>

Date::Calc - L<pod|Date::Calc>, L<http://www.perladvent.org/2006/20/>

Devel::Cover - L<pod|Devel::Cover>, L<http://www.perladvent.org/2006/21/>

PAR::Dist - L<pod|PAR::Dist>, L<http://www.perladvent.org/2006/22/>

PAR::Dist::FromCPAN - L<pod|PAR::Dist::FromCPAN>, L<http://www.perladvent.org/2006/22/>

criticism - L<pod|criticism>, L<http://www.perladvent.org/2006/23/>

DBD::AnyData - L<pod|DBD::AnyData>, L<http://www.perladvent.org/2006/24/>

DateTime::Calendar::Discordian - L<pod|DateTime::Calendar::Discordian>, L<http://www.perladvent.org/2006/25/>



=head1 AUTHOR

David Westbrook (CPAN: davidrw), C<< <dwestbrook at gmail.com> >>


=head1 SUPPORT

You can find documentation for this module with the perldoc command.

    perldoc Bundle::Advent::Year2006

Otherwise, see L<Advent::Bundles>.


=head1 COPYRIGHT & LICENSE

Copyright 2008 David Westbrook, all rights reserved.

This program is free software; you can redistribute it and/or modify it
under the same terms as Perl itself.


=cut
