package Bundle::Advent::Year2004;

our $VERSION = '0.02';

1;

__END__

=pod

=head1 NAME

Bundle::Advent::Year2004 - Modules of the 2004 Perl Advent Calendar

=head1 VERSION

Version 0.02

=head1 SYNOPSIS

Bundle for the modules featured in the 2004 Perl Advent Calendar:
L<http://www.perladvent.org/2004/>.

    $ cpan Bundle::Advent::Year2004

=head1 CONTENTS

DateTime - L<pod|DateTime>, L<http://www.perladvent.org/2004/01/>

Term::ANSIColor - L<pod|Term::ANSIColor>, L<http://www.perladvent.org/2004/02/>

Class::Accessor::Chained - L<pod|Class::Accessor::Chained>, L<http://www.perladvent.org/2004/03/>

String::ShellQuote - L<pod|String::ShellQuote>, L<http://www.perladvent.org/2004/04/>

CPAN::Mini - L<pod|CPAN::Mini>, L<http://www.perladvent.org/2004/05/>

Module::Pluggable - L<pod|Module::Pluggable>, L<http://www.perladvent.org/2004/06/>

Term::ProgressBar - L<pod|Term::ProgressBar>, L<http://www.perladvent.org/2004/07/>

Data::Dumper::Simple - L<pod|Data::Dumper::Simple>, L<http://www.perladvent.org/2004/08/>

Proc::Daemon - L<pod|Proc::Daemon>, L<http://www.perladvent.org/2004/09/>

Data::UUID - L<pod|Data::UUID>, L<http://www.perladvent.org/2004/10/>

Encode - L<pod|Encode>, L<http://www.perladvent.org/2004/11/>

Text::Unidecode - L<pod|Text::Unidecode>, L<http://www.perladvent.org/2004/12/>

Devel::Trace - L<pod|Devel::Trace>, L<http://www.perladvent.org/2004/13/>

SQL::Abstract - L<pod|SQL::Abstract>, L<http://www.perladvent.org/2004/14/>

Archive::Extract - L<pod|Archive::Extract>, L<http://www.perladvent.org/2004/15/>

Cache::Cache - L<pod|Cache::Cache>, L<http://www.perladvent.org/2004/16/>

Mac::Glue - L<pod|Mac::Glue>, L<http://www.perladvent.org/2004/17/>

Acme::Drunk - L<pod|Acme::Drunk>, L<http://www.perladvent.org/2004/18/>

Filesys::Virtual - L<pod|Filesys::Virtual>, L<http://www.perladvent.org/2004/20/>

Sys::Hostname - L<pod|Sys::Hostname>, L<http://www.perladvent.org/2004/21/>



=head1 AUTHOR

David Westbrook (CPAN: davidrw), C<< <dwestbrook at gmail.com> >>


=head1 SUPPORT

You can find documentation for this module with the perldoc command.

    perldoc Bundle::Advent::Year2004

Otherwise, see L<Advent::Bundles>.


=head1 COPYRIGHT & LICENSE

Copyright 2008 David Westbrook, all rights reserved.

This program is free software; you can redistribute it and/or modify it
under the same terms as Perl itself.


=cut
