package Bundle::Advent::Year2009;

our $VERSION = '0.04';

1;

__END__

=pod

=head1 NAME

Bundle::Advent::Year2009 - Modules of the 2009 Perl Advent Calendar

=head1 VERSION

Version 0.04

=head1 SYNOPSIS

Bundle for the modules featured in the 2009 Perl Advent Calendar:
L<http://www.perladvent.org/2009/>.

    $ cpan Bundle::Advent::Year2009

=head1 CONTENTS

No peeking!!


=head1 AUTHOR

David Westbrook (CPAN: davidrw), C<< <dwestbrook at gmail.com> >>


=head1 SUPPORT

You can find documentation for this module with the perldoc command.

    perldoc Bundle::Advent::Year2009

Otherwise, see L<Advent::Bundles>.


=head1 COPYRIGHT & LICENSE

Copyright 2009 David Westbrook, all rights reserved.

This program is free software; you can redistribute it and/or modify it
under the same terms as Perl itself.


=cut
