package Bundle::Advent::Year2008;

our $VERSION = '0.03';

1;

__END__

=pod

=head1 NAME

Bundle::Advent::Year2008 - Modules of the 2008 Perl Advent Calendar

=head1 VERSION

Version 0.03

=head1 SYNOPSIS

Bundle for the modules featured in the 2008 Perl Advent Calendar:
L<http://www.perladvent.org/2008/>.

    $ cpan Bundle::Advent::Year2008

=head1 CONTENTS

ToolSet - L<pod|ToolSet>, L<http://www.perladvent.org/2008/01/>

Math::Prime::TiedArray - L<pod|Math::Prime::TiedArray>, L<http://www.perladvent.org/2008/02/>

Math::BigApprox - L<pod|Math::BigApprox>, L<http://www.perladvent.org/2008/03/>

Lingua::Ident - L<pod|Lingua::Ident>, L<http://www.perladvent.org/2008/04/>

Test::Harness - L<pod|Test::Harness>, L<http://www.perladvent.org/2008/05/>

Sub::Curry - L<pod|Sub::Curry>, L<http://www.perladvent.org/2008/06/>

IPC::Filter - L<pod|IPC::Filter>, L<http://www.perladvent.org/2008/08/>

# Bundle::* L<http://search.cpan.org/perldoc?CPAN#Bundles> L<http://www.perladvent.org/2008/10/>

Module::ScanDeps - L<pod|Module::ScanDeps>, L<http://www.perladvent.org/2008/11/>

Tk - L<pod|Tk>, L<http://www.perladvent.org/2008/12/>

Text::SpellChecker - L<pod|Text::SpellChecker>, L<http://www.perladvent.org/2008/13/>

Lingua::Translate - L<pod|Lingua::Translate>, L<http://www.perladvent.org/2008/14/>

# ForkBlock L<http://perlmonks.org/?node_id=59619> L<http://www.perladvent.org/2008/15/>

SelfLoader - L<pod|SelfLoader>, L<http://www.perladvent.org/2008/16/>

Config::General - L<pod|Config::General>, L<http://www.perladvent.org/2008/18/>

Tie::OneOff - L<pod|Tie::OneOff>, L<http://www.perladvent.org/2008/20/>

Text::Metaphone - L<pod|Text::Metaphone>, L<http://www.perladvent.org/2008/20/>

String::Approx - L<pod|String::Approx>, L<http://www.perladvent.org/2008/20/>

App::Asciio - L<pod|App::Asciio>, L<http://www.perladvent.org/2008/21/>

Regexp::Subst::Parallel - L<pod|Regexp::Subst::Parallel>, L<http://www.perladvent.org/2008/22/>

Test::Perl::Critic::Progressive - L<pod|Test::Perl::Critic::Progressive>, L<http://www.perladvent.org/2008/23/>

Sort::Half::Maker - L<pod|Sort::Half::Maker>, L<http://www.perladvent.org/2008/24/>

Term::Animation - L<pod|Term::Animation>, L<http://www.perladvent.org/2008/25/>



=head1 AUTHOR

David Westbrook (CPAN: davidrw), C<< <dwestbrook at gmail.com> >>


=head1 SUPPORT

You can find documentation for this module with the perldoc command.

    perldoc Bundle::Advent::Year2008

Otherwise, see L<Advent::Bundles>.


=head1 COPYRIGHT & LICENSE

Copyright 2008 David Westbrook, all rights reserved.

This program is free software; you can redistribute it and/or modify it
under the same terms as Perl itself.


=cut
