package Bundle::Advent::Year2005;

our $VERSION = '0.02';

1;

__END__

=pod

=head1 NAME

Bundle::Advent::Year2005 - Modules of the 2005 Perl Advent Calendar

=head1 VERSION

Version 0.02

=head1 SYNOPSIS

Bundle for the modules featured in the 2005 Perl Advent Calendar:
L<http://www.perladvent.org/2005/>.

    $ cpan Bundle::Advent::Year2005

=head1 CONTENTS

HTML::Parser - L<pod|HTML::Parser>, L<http://www.perladvent.org/2005/05/>

LWP::Simple - L<pod|LWP::Simple>, L<http://www.perladvent.org/2005/05/>

Lingua::EN::Numbers::Ordinate - L<pod|Lingua::EN::Numbers::Ordinate>, L<http://www.perladvent.org/2005/05/>

Perl::Tidy - L<pod|Perl::Tidy>, L<http://www.perladvent.org/2005/05/>

Text::Table - L<pod|Text::Table>, L<http://www.perladvent.org/2005/05/>

Interpolation - L<pod|Interpolation>, L<http://www.perladvent.org/2005/06/>

spod5 - L<pod|spod5>, L<http://www.perladvent.org/2005/07/>

bignum - L<pod|bignum>, L<http://www.perladvent.org/2005/08/>

CGI::Ajax - L<pod|CGI::Ajax>, L<http://www.perladvent.org/2005/09/>

PPT - L<pod|PPT>, L<http://www.perladvent.org/2005/10/>

Perl6::Junction - L<pod|Perl6::Junction>, L<http://www.perladvent.org/2005/11/>

re - L<pod|re>, L<http://www.perladvent.org/2005/12/>

Regexp::Keep - L<pod|Regexp::Keep>, L<http://www.perladvent.org/2005/13/>

HTML::Lint - L<pod|HTML::Lint>, L<http://www.perladvent.org/2005/14/>

Data::COW - L<pod|Data::COW>, L<http://www.perladvent.org/2005/15/>

XML::RSS::SimpleGen - L<pod|XML::RSS::SimpleGen>, L<http://www.perladvent.org/2005/16/>

Acme::POE::Knee - L<pod|Acme::POE::Knee>, L<http://www.perladvent.org/2005/17/>

Regexp::Assemble - L<pod|Regexp::Assemble>, L<http://www.perladvent.org/2005/18/>

Test::Perl::Critic - L<pod|Test::Perl::Critic>, L<http://www.perladvent.org/2005/19/>

Perl::Compare - L<pod|Perl::Compare>, L<http://www.perladvent.org/2005/20/>

Want - L<pod|Want>, L<http://www.perladvent.org/2005/21/>

Module::CoreList - L<pod|Module::CoreList>, L<http://www.perladvent.org/2005/22/>

Sort::Maker - L<pod|Sort::Maker>, L<http://www.perladvent.org/2005/23/>

enum - L<pod|enum>, L<http://www.perladvent.org/2005/24/>

enum::hash - L<pod|enum::hash>, L<http://www.perladvent.org/2005/24/>

Text::FIGlet - L<pod|Text::FIGlet>, L<http://www.perladvent.org/2005/25/>



=head1 AUTHOR

David Westbrook (CPAN: davidrw), C<< <dwestbrook at gmail.com> >>


=head1 SUPPORT

You can find documentation for this module with the perldoc command.

    perldoc Bundle::Advent::Year2005

Otherwise, see L<Advent::Bundles>.


=head1 COPYRIGHT & LICENSE

Copyright 2008 David Westbrook, all rights reserved.

This program is free software; you can redistribute it and/or modify it
under the same terms as Perl itself.


=cut
