package Bundle::Advent::Year2001;

our $VERSION = '0.02';

1;

__END__

=pod

=head1 NAME

Bundle::Advent::Year2001 - Modules of the 2001 Perl Advent Calendar

=head1 VERSION

Version 0.02

=head1 SYNOPSIS

Bundle for the modules featured in the 2001 Perl Advent Calendar:
L<http://www.perladvent.org/2001/>.

    $ cpan Bundle::Advent::Year2001

=head1 CONTENTS

Mail::Audit - L<pod|Mail::Audit>, L<http://www.perladvent.org/2001/01/>

Mail::ListDetector - L<pod|Mail::ListDetector>, L<http://www.perladvent.org/2001/02/>

Tie::DBI - L<pod|Tie::DBI>, L<http://www.perladvent.org/2001/03/>

File::Spec - L<pod|File::Spec>, L<http://www.perladvent.org/2001/04/>

XML::XPath - L<pod|XML::XPath>, L<http://www.perladvent.org/2001/05/>

Acme::Pony - L<pod|Acme::Pony>, L<http://www.perladvent.org/2001/06/>

Scalar::Util - L<pod|Scalar::Util>, L<http://www.perladvent.org/2001/07/>

List::Util - L<pod|List::Util>, L<http://www.perladvent.org/2001/08/>

GraphViz - L<pod|GraphViz>, L<http://www.perladvent.org/2001/09/>

Test::More - L<pod|Test::More>, L<http://www.perladvent.org/2001/10/>

POE - L<pod|POE>, L<http://www.perladvent.org/2001/11/>

POE::Component::Client::HTTP - L<pod|POE::Component::Client::HTTP>, L<http://www.perladvent.org/2001/12/>

Crypt::Solitaire - L<pod|Crypt::Solitaire>, L<http://www.perladvent.org/2001/13/>

Spreadsheet::WriteExcel - L<pod|Spreadsheet::WriteExcel>, L<http://www.perladvent.org/2001/14/>

Pod::Coverage - L<pod|Pod::Coverage>, L<http://www.perladvent.org/2001/15/>

Tie::Hash::Cannabinol - L<pod|Tie::Hash::Cannabinol>, L<http://www.perladvent.org/2001/16/>

Attribute::TieClasses - L<pod|Attribute::TieClasses>, L<http://www.perladvent.org/2001/17/>

Attribute::Overload - L<pod|Attribute::Overload>, L<http://www.perladvent.org/2001/18/>

Class::MethodMaker - L<pod|Class::MethodMaker>, L<http://www.perladvent.org/2001/19/>

ExtUtils::ModuleMaker - L<pod|ExtUtils::ModuleMaker>, L<http://www.perladvent.org/2001/20/>

Exporter::Simple - L<pod|Exporter::Simple>, L<http://www.perladvent.org/2001/21/>

Text::Autoformat - L<pod|Text::Autoformat>, L<http://www.perladvent.org/2001/22/>

Inline::Files - L<pod|Inline::Files>, L<http://www.perladvent.org/2001/23/>

Quantum::Superpositions - L<pod|Quantum::Superpositions>, L<http://www.perladvent.org/2001/24/>

Parse::RecDescent - L<pod|Parse::RecDescent>, L<http://www.perladvent.org/2001/25/>



=head1 AUTHOR

David Westbrook (CPAN: davidrw), C<< <dwestbrook at gmail.com> >>


=head1 SUPPORT

You can find documentation for this module with the perldoc command.

    perldoc Bundle::Advent::Year2001

Otherwise, see L<Advent::Bundles>.


=head1 COPYRIGHT & LICENSE

Copyright 2008 David Westbrook, all rights reserved.

This program is free software; you can redistribute it and/or modify it
under the same terms as Perl itself.


=cut
